/* Scandinavian conversions for SemWare's TSE editor V2.0. To make
   this SAL macro operational, invoke the main menu (F10), choose
   "Macro", choose "Compile" and press Enter at "Execute Macro".

..................................................................
Prof. Timo Salmi      Co-moderator of comp.archives.msdos.announce
Moderating at garbo.uwasa.fi anonymous FTP archives  193.166.120.5
Faculty of Accounting & Industrial Management; University of Vaasa
Internet: ts@uwasa.fi   BBS +(358)-61-3170972; FIN-65101,  Finland
*/

// The contents of a simple help, tied later to the CtrlAlt-H key
helpdef tHelpData
  title = "TOASC.S HELP"           // The help's caption
  x = 10                           // Location
  y = 3
  // The actual help text
  " Prof. Timo Salmi's Scandinavian conversions"
  ""
  " These procedures are for converting the Scandinavian "
  " characters between different conventions."
  ""
  " You can use <F11> to invoke the command menu after "
  " first exiting this help. "
  ""
  " Last updated Sat 26-November-1994 20:02:03 "
end  /* tHelpData */

// Convert 8-bit Scandinavian letters to their local 7-bit counterparts
proc timoToAsc()
  lReplace("","}","gn")
  lReplace("","{","gn")
  lReplace("","|","gn")
  lReplace("","]","gn")
  lReplace("","[","gn")
  lReplace("","\","gn")
end

// Convert local 7-bit Scandinavian letters to their 8-bit counterparts
proc timoToIbm()
  lReplace("}","","gn")
  lReplace("{","","gn")
  lReplace("|","","gn")
  lReplace("]","","gn")
  lReplace("[","","gn")
  lReplace("\","","gn")
end

// Convert a second alternative of 8-bit Scandinavian letters to their
// local 7-bit counterparts
proc timoToIbm2()
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
end

// Covert Mac Scandinavian characters to their IBM equivalents
proc timoMac2Pc()
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
  lReplace("","","gn")
end

// New keys and menus **************************************************
forward Menu tIbmAscMenu()
forward proc tDisableNewKeys()

// Add the new key definitions
keydef new_keys
  <CtrlAlt 1>      timoToAsc()
  <CtrlAlt 2>      timoToIbm()
  <CtrlAlt 3>      timoToIbm2()
  <CtrlAlt 4>      timoMac2Pc()
  <CtrlAlt 0>      tDisableNewKeys()
  <CtrlAlt H>      QuickHelp(tHelpData)
  <F11>            tIbmAscMenu()
end

// Disabling the new extra keys ***************************************
proc tDisableNewKeys()
  if YesNo("Disable the extra keys:") == 1 Disable(new_keys) endif
end

// The IbmAsc menu ****************************************************
Menu tIbmAscMenu()
  Title = "Timo's conversion menu"
  x = 40
  y = 3
  history
  "To&Asc (7-bit)     <CtrlAlt 1>"   , timoToAsc()
  "To&Ibm (8-bit)     <CtrlAlt 2>"   , timoToIbm()
  "Toibm&2 (8-bit)    <CtrlAlt 3>"   , timoToIbm2()
  "Mac2P&C (8-bit)    <CtrlAlt 4>"   , timoMac2Pc()
  "",,Divide
  "Disable &new keys  <CtrlAlt 0>"   , tDisableNewKeys()
  "&Help              <CtrlAlt H>"   , QuickHelp(tHelpData)
  "This Menu         <F11>"
end  /* tIbmAscMenu */

proc Main()
  Enable (new_keys)
  tIbmAscMenu()
end
